@@ -18,14 +18,14 @@
    this.year <- substr(date, x[1], x[1] + attr(x, "match.length") - 1)
    
    # echo output to screen
-   cat("##\n## Markov Chain Monte Carlo Package (MCMCpack)\n")
-   cat("## Copyright (C) 2003-", this.year,
-      " Andrew D. Martin, Kevin M. Quinn, and Jong Hee Park\n", sep="")
-   cat("##\n## Support provided by the U.S. National Science Foundation\n")
-   cat("## (Grants SES-0350646 and SES-0350613)\n##\n")
-   require(coda, quietly=TRUE)
-   require(MASS, quietly=TRUE)
-   require(stats, quietly=TRUE)
+   packageStartupMessage("##\n## Markov Chain Monte Carlo Package (MCMCpack)")
+   packageStartupMessage("## Copyright (C) 2003-", this.year,
+      " Andrew D. Martin, Kevin M. Quinn, and Jong Hee Park", sep="")
+   packageStartupMessage("##\n## Support provided by the U.S. National Science Foundation")
+   packageStartupMessage("## (Grants SES-0350646 and SES-0350613)\n##")
+   ## require(coda, quietly=TRUE)
+   ## require(MASS, quietly=TRUE)
+   ## require(stats, quietly=TRUE)
 }
 
 .onUnload <- function(libpath) {
